"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _mockGit = require("mock-git");

var _mockGit2 = _interopRequireDefault(_mockGit);

var _mockBin = require("mock-bin");

var _mockBin2 = _interopRequireDefault(_mockBin);

var _tmpPromise = require("tmp-promise");

var _tmpPromise2 = _interopRequireDefault(_tmpPromise);

var _path = require("path");

var _path2 = _interopRequireDefault(_path);

var _fs = require("mz/fs");

var _fs2 = _interopRequireDefault(_fs);

var _pmock = require("pmock");

var _pmock2 = _interopRequireDefault(_pmock);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

class TestEnvironment {
  constructor() {
    this._unmock = [];
    this._spyLogFile = undefined;
    this.__makeSpyJs = undefined;
  }

  setAllStagedFiles(files = []) {
    var _this = this;

    return _asyncToGenerator(function* () {
      _this._unmock.push((yield (0, _mockGit2.default)(`${_this._makeSpyJs("git")} for (const file of ${JSON.stringify(files)}) console.log(file);`, "diff-index")));
    })();
  }

  setPartialFiles(files = []) {
    var _this2 = this;

    return _asyncToGenerator(function* () {
      _this2._unmock.push((yield (0, _mockGit2.default)(`${_this2._makeSpyJs("git")} for (const file of ${JSON.stringify(files)}) console.log(file);`, "diff")));
    })();
  }

  get log() {
    var _this3 = this;

    return _asyncToGenerator(function* () {
      if (yield _fs2.default.exists(_this3._spyLogFile)) {
        const logContent = yield _fs2.default.readFile(_this3._spyLogFile, "utf8");
        return logContent.split("\n").filter(Boolean).map(function (line) {
          return JSON.parse(line).join(" ");
        });
      }
      return [];
    })();
  }

  mockBin(name) {
    var _this4 = this;

    return _asyncToGenerator(function* () {
      _this4._unmock.push((yield (0, _mockBin2.default)(name, "node", _this4._makeSpyJs(name))));
    })();
  }

  _makeSpyJs(...prefix) {
    return `
      require("fs").appendFileSync(${JSON.stringify(this._spyLogFile)}, JSON.stringify(${JSON.stringify(prefix)}.concat(process.argv.slice(2))) + "\\n", "utf8");
    `;
  }

  setup() {
    var _this5 = this;

    return _asyncToGenerator(function* () {
      _this5._spyLogFile = yield _tmpPromise2.default.tmpName();
      _this5._unmock.push((yield (0, _mockGit2.default)(_this5._makeSpyJs("git"), "add")));
      const cwdMock = _pmock2.default.cwd("/path/to/repo");
      _this5._unmock.push(function () {
        return cwdMock.reset();
      });
      yield _this5.setAllStagedFiles();
      yield _this5.setPartialFiles();
    })();
  }
  cleanup() {
    for (const unmockOne of this._unmock) {
      unmockOne();
    }
    this._unmock = [];
  }
}
exports.default = TestEnvironment;