"use strict";

var _ = require("../");

var _2 = _interopRequireDefault(_);

var _TestEnvironment = require("TestEnvironment");

var _TestEnvironment2 = _interopRequireDefault(_TestEnvironment);

var _path = require("path");

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

describe("git-exec-and-restage", () => {
  const env = new _TestEnvironment2.default();
  beforeEach(() => env.setup());
  afterEach(() => env.cleanup());
  it("no command, no args and no files staged", _asyncToGenerator(function* () {
    yield expect((0, _2.default)()).rejects.toMatchSnapshot();
  }));
  it("with command, no args and no files", _asyncToGenerator(function* () {
    yield env.mockBin("prettier");
    yield (0, _2.default)(["prettier"]);
    expect((yield env.log)).toMatchSnapshot();
  }));
  it("with command and arguments, no files", _asyncToGenerator(function* () {
    yield env.mockBin("prettier");
    yield (0, _2.default)(["prettier", "--write", "--"]);
    expect((yield env.log)).toMatchSnapshot();
  }));
  it("with command, arguments, fully staged file, no partials", _asyncToGenerator(function* () {
    yield env.mockBin("prettier");
    yield env.setAllStagedFiles(["fullystaged.js"]);
    yield (0, _2.default)(["prettier", "--write", "--", "fullystaged.js"]);
    expect((yield env.log)).toMatchSnapshot();
  }));
  it("with command+args, mix of fully and partially staged files", _asyncToGenerator(function* () {
    yield env.mockBin("prettier");
    yield env.setAllStagedFiles(["fullystaged.js", "partiallystaged.js"]);
    yield env.setPartialFiles(["partiallystaged.js"]);
    yield (0, _2.default)(["prettier", "--write", "--", "fullystaged.js", "partiallystaged.js"]);
    expect((yield env.log)).toMatchSnapshot();
  }));
  it("with command+args, files implicit", _asyncToGenerator(function* () {
    yield env.mockBin("prettier");
    yield env.setAllStagedFiles(["fullystaged.js", "partiallystaged.js"]);
    yield env.setPartialFiles(["partiallystaged.js"]);
    yield (0, _2.default)(["prettier", "--write", "--"]);
    expect((yield env.log)).toMatchSnapshot();
  }));
  it("with command+args, pick one of multiple files", _asyncToGenerator(function* () {
    yield env.mockBin("prettier");
    yield env.setAllStagedFiles(["fullystaged1.js", "fullystaged2.js", "partiallystaged1.js", "partiallystaged2.js"]);
    yield env.setPartialFiles(["partiallystaged1.js", "partiallystaged2.js"]);
    yield (0, _2.default)(["prettier", "--write", "--", "fullystaged1.js"]);
    expect((yield env.log)).toMatchSnapshot();
  }));
  it("with command+args and mixed status, absolute paths", _asyncToGenerator(function* () {
    yield env.mockBin("prettier");
    yield env.setAllStagedFiles(["fullystaged.js", "partiallystaged.js"]);
    yield env.setPartialFiles(["partiallystaged.js"]);
    yield (0, _2.default)(["prettier", "--write", "--", _path2.default.join(process.cwd(), "fullystaged.js"), _path2.default.join(process.cwd(), "partiallystaged.js")]);
    expect((yield env.log)).toMatchSnapshot();
  }));
});